# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.container
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ContainerEvent(EventObject_a3d70b03):
    """
    Struct Class

    This event is fired when an element is inserted in a container.

    See Also:
        `API ContainerEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1container_1_1ContainerEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.ContainerEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.container.ContainerEvent'
    """Literal Constant ``com.sun.star.container.ContainerEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Accessor: typing.Optional[object] = None, Element: typing.Optional[object] = None, ReplacedElement: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Accessor (object, optional): Accessor value.
            Element (object, optional): Element value.
            ReplacedElement (object, optional): ReplacedElement value.
        """

        if isinstance(Source, ContainerEvent):
            oth: ContainerEvent = Source
            self.Source = oth.Source
            self.Accessor = oth.Accessor
            self.Element = oth.Element
            self.ReplacedElement = oth.ReplacedElement
            return

        kargs = {
            "Source": Source,
            "Accessor": Accessor,
            "Element": Element,
            "ReplacedElement": ReplacedElement,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._accessor = kwargs["Accessor"]
        self._element = kwargs["Element"]
        self._replaced_element = kwargs["ReplacedElement"]
        inst_keys = ('Accessor', 'Element', 'ReplacedElement')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Accessor(self) -> object:
        """
        It contains the accessor to the element which is inserted or removed.
        
        The type and the value of the accessor depends on the service.
        """
        return self._accessor

    @Accessor.setter
    def Accessor(self, value: object) -> None:
        self._accessor = value

    @property
    def Element(self) -> object:
        """
        This contains the element that was inserted or removed.
        """
        return self._element

    @Element.setter
    def Element(self, value: object) -> None:
        self._element = value

    @property
    def ReplacedElement(self) -> object:
        """
        This contains the replaced element.
        """
        return self._replaced_element

    @ReplacedElement.setter
    def ReplacedElement(self, value: object) -> None:
        self._replaced_element = value


__all__ = ['ContainerEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XControlAccess(XInterface_8f010a43):
    """
    Generic control access interface.
    
    Use this interface to access user interface controls supported by the implementing service. The supported controls, control properties and the appropriate values are documented in the description of the implementing service.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XControlAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.XControlAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.dialogs.XControlAccess'

    @abstractmethod
    def getControlProperty(self, aControlName: str, aControlProperty: str) -> object:
        """
        Query for a control property.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setControlProperty(self, aControlName: str, aControlProperty: str, aValue: object) -> None:
        """
        Change a control property.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XControlAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_axis import XAxis as XAxis_796b0939

class XCoordinateSystem(XInterface_8f010a43):
    """

    See Also:
        `API XCoordinateSystem <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XCoordinateSystem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XCoordinateSystem'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XCoordinateSystem'

    @abstractmethod
    def getAxisByDimension(self, nDimension: int, nIndex: int) -> XAxis_796b0939:
        """
        The dimension says whether it is a x, y or z axis.
        
        The index indicates whether it is a primary or a secondary axis or maybe more in future. Use nIndex == 0 for a primary axis. An empty Reference will be returned if the given nDimension and nIndex are in the valid range but no axis is set for those values. An IndexOutOfBoundsException will be thrown if nDimension is lower than 0 or greater than the value returned by getDimension() and/or if nIndex is lower 0 or greater than the value returned by getMaxAxisIndexByDimension(nDimension).

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getCoordinateSystemType(self) -> str:
        """
        identifies the type of coordinate system (e.g.
        
        Cartesian, polar ...)
        """
        ...
    @abstractmethod
    def getDimension(self) -> int:
        """
        the dimension of the coordinate-system.
        """
        ...
    @abstractmethod
    def getMaximumAxisIndexByDimension(self, nDimension: int) -> int:
        """
        In one dimension there could be several axes to enable main and secondary axis and maybe more in future.
        
        This method returns the maximum index at which an axis exists for the given dimension. It is allowed that some indexes in between do not have an axis.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getViewServiceName(self) -> str:
        """
        return a service name from which the view component for this coordinate system can be created
        """
        ...
    @abstractmethod
    def setAxisByDimension(self, nDimension: int, xAxis: XAxis_796b0939, nIndex: int) -> None:
        """
        The dimension says whether it is a x, y or z axis.
        
        The index says whether it is a primary or a secondary axis. Use nIndex == 0 for a primary axis.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XCoordinateSystem']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class ConnectorType(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.ConnectorType", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.ConnectorType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.ConnectorType import CURVE as CONNECTOR_TYPE_CURVE
        from com.sun.star.drawing.ConnectorType import LINE as CONNECTOR_TYPE_LINE
        from com.sun.star.drawing.ConnectorType import LINES as CONNECTOR_TYPE_LINES
        from com.sun.star.drawing.ConnectorType import STANDARD as CONNECTOR_TYPE_STANDARD

        class ConnectorType(uno.Enum):
            """
            Enum Class


            See Also:
                `API ConnectorType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.ConnectorType', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.ConnectorType'
            __ooo_type_name__: str = 'enum'

            CURVE = CONNECTOR_TYPE_CURVE
            """
            the ConnectorShape is drawn as a curve
            """
            LINE = CONNECTOR_TYPE_LINE
            """
            the ConnectorShape is drawn as a straight line

            This is the PolygonKind for a LineShape.
            """
            LINES = CONNECTOR_TYPE_LINES
            """
            the connector is drawn with three lines
            """
            STANDARD = CONNECTOR_TYPE_STANDARD
            """
            the graphic is rendered in the default color style of the output device,

            use the length measurement.

            the connector is drawn with three lines, with the middle line perpendicular to the other two
            """
    else:
        # keep document generators happy
        from ...lo.drawing.connector_type import ConnectorType as ConnectorType


__all__ = ['ConnectorType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_fast_context_handler import XFastContextHandler as XFastContextHandler_361e0f5c
if typing.TYPE_CHECKING:
    from .x_locator import XLocator as XLocator_a3fb0aff

class XFastDocumentHandler(XFastContextHandler_361e0f5c):
    """
    receives notification of sax document events from a XFastParser
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API XFastDocumentHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastDocumentHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XFastDocumentHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XFastDocumentHandler'

    @abstractmethod
    def endDocument(self) -> None:
        """
        called by the parser after the last XML element of a stream is processed.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def processingInstruction(self, aTarget: str, aData: str) -> None:
        """
        receives notification of a processing instruction.
        
        **since**
        
            LibreOffice 6.0

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def setDocumentLocator(self, xLocator: XLocator_a3fb0aff) -> None:
        """
        receives an object for locating the origin of SAX document events.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startDocument(self) -> None:
        """
        called by the parser when parsing of an XML stream is started.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...

__all__ = ['XFastDocumentHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_node import XNode as XNode_83fb09a5
if typing.TYPE_CHECKING:
    from .x_attr import XAttr as XAttr_840309ba
    from .x_node_list import XNodeList as XNodeList_ae540b41

class XElement(XNode_83fb09a5):
    """

    See Also:
        `API XElement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XElement'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XElement'

    @abstractmethod
    def getAttribute(self, name: str) -> str:
        """
        Retrieves an attribute value by name.
        """
        ...
    @abstractmethod
    def getAttributeNS(self, namespaceURI: str, localName: str) -> str:
        """
        Retrieves an attribute value by local name and namespace URI.
        """
        ...
    @abstractmethod
    def getAttributeNode(self, name: str) -> XAttr_840309ba:
        """
        Retrieves an attribute node by name.
        """
        ...
    @abstractmethod
    def getAttributeNodeNS(self, namespaceURI: str, localName: str) -> XAttr_840309ba:
        """
        Retrieves an Attr node by local name and namespace URI.
        """
        ...
    @abstractmethod
    def getElementsByTagName(self, name: str) -> XNodeList_ae540b41:
        """
        Returns a NodeList of all descendant Elements with a given tag name, in the order in which they are encountered in a preorder traversal of this Element tree.
        """
        ...
    @abstractmethod
    def getElementsByTagNameNS(self, namespaceURI: str, localName: str) -> XNodeList_ae540b41:
        """
        Returns a NodeList of all the descendant Elements with a given local name and namespace URI in the order in which they are encountered in a preorder traversal of this Element tree.
        """
        ...
    @abstractmethod
    def getTagName(self) -> str:
        """
        The name of the element.
        """
        ...
    @abstractmethod
    def hasAttribute(self, name: str) -> bool:
        """
        Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        """
        ...
    @abstractmethod
    def hasAttributeNS(self, namespaceURI: str, localName: str) -> bool:
        """
        Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        """
        ...
    @abstractmethod
    def removeAttribute(self, name: str) -> None:
        """
        Removes an attribute by name.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def removeAttributeNS(self, namespaceURI: str, localName: str) -> None:
        """
        Removes an attribute by local name and namespace URI.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def removeAttributeNode(self, oldAttr: XAttr_840309ba) -> XAttr_840309ba:
        """
        Removes the specified attribute node.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly. NOT_FOUND_ERR: Raised if oldAttr is not an attribute of the element.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setAttribute(self, name: str, value: str) -> None:
        """
        Adds a new attribute.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified name contains an illegal character. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setAttributeNS(self, namespaceURI: str, qualifiedName: str, value: str) -> None:
        """
        Adds a new attribute.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character, per the XML 1.0 specification . NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly. NAMESPACE_ERR: Raised if the qualifiedName is malformed per the Namespaces in XML specification, if the qualifiedName has a prefix and the namespaceURI is null, if the qualifiedName has a prefix that is \"xml\" and the namespaceURI is different from \" http://www.w3.org/XML/1998/namespace\", or if the qualifiedName, or its prefix, is \"xmlns\" and the namespaceURI is different from \" http://www.w3.org/2000/xmlns/\". NOT_SUPPORTED_ERR: Always thrown if the current document does not support the \"XML\" feature, since namespaces were defined by XML.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setAttributeNode(self, newAttr: XAttr_840309ba) -> XAttr_840309ba:
        """
        Adds a new attribute node.
        
        Throws: DOMException - WRONG_DOCUMENT_ERR: Raised if newAttr was created from a different document than the one that created the element. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly. INUSE_ATTRIBUTE_ERR: Raised if newAttr is already an attribute of another Element object. The DOM user must explicitly clone Attr nodes to re-use them in other elements.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setAttributeNodeNS(self, newAttr: XAttr_840309ba) -> XAttr_840309ba:
        """
        Adds a new attribute.
        
        Throws: DOMException - WRONG_DOCUMENT_ERR: Raised if newAttr was created from a different document than the one that created the element. NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly. INUSE_ATTRIBUTE_ERR: Raised if newAttr is already an attribute of another Element object. The DOM user must explicitly clone Attr nodes to re-use them in other elements. NOT_SUPPORTED_ERR: Always thrown if the current document does not support the \"XML\" feature, since namespaces were defined by XML.

        Raises:
            DOMException: ``DOMException``
        """
        ...

__all__ = ['XElement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.reflection.core_reflection import CoreReflection as CoreReflection
from ...lo.reflection.field_access_mode import FieldAccessMode as FieldAccessMode
from ...lo.reflection.invalid_type_name_exception import InvalidTypeNameException as InvalidTypeNameException
from ...lo.reflection.invocation_target_exception import InvocationTargetException as InvocationTargetException
from ...lo.reflection.method_mode import MethodMode as MethodMode
from ...lo.reflection.no_such_type_name_exception import NoSuchTypeNameException as NoSuchTypeNameException
from ...lo.reflection.param_info import ParamInfo as ParamInfo
from ...lo.reflection.param_mode import ParamMode as ParamMode
from ...lo.reflection.proxy_factory import ProxyFactory as ProxyFactory
from ...lo.reflection.type_description_manager import TypeDescriptionManager as TypeDescriptionManager
from ...lo.reflection.type_description_provider import TypeDescriptionProvider as TypeDescriptionProvider
from ...lo.reflection.type_description_search_depth import TypeDescriptionSearchDepth as TypeDescriptionSearchDepth
from ...lo.reflection.x_array_type_description import XArrayTypeDescription as XArrayTypeDescription
from ...lo.reflection.x_compound_type_description import XCompoundTypeDescription as XCompoundTypeDescription
from ...lo.reflection.x_constant_type_description import XConstantTypeDescription as XConstantTypeDescription
from ...lo.reflection.x_constants_type_description import XConstantsTypeDescription as XConstantsTypeDescription
from ...lo.reflection.x_enum_type_description import XEnumTypeDescription as XEnumTypeDescription
from ...lo.reflection.x_idl_array import XIdlArray as XIdlArray
from ...lo.reflection.x_idl_class import XIdlClass as XIdlClass
from ...lo.reflection.x_idl_class_provider import XIdlClassProvider as XIdlClassProvider
from ...lo.reflection.x_idl_field import XIdlField as XIdlField
from ...lo.reflection.x_idl_field2 import XIdlField2 as XIdlField2
from ...lo.reflection.x_idl_member import XIdlMember as XIdlMember
from ...lo.reflection.x_idl_method import XIdlMethod as XIdlMethod
from ...lo.reflection.x_idl_reflection import XIdlReflection as XIdlReflection
from ...lo.reflection.x_indirect_type_description import XIndirectTypeDescription as XIndirectTypeDescription
from ...lo.reflection.x_interface_attribute_type_description import XInterfaceAttributeTypeDescription as XInterfaceAttributeTypeDescription
from ...lo.reflection.x_interface_attribute_type_description2 import XInterfaceAttributeTypeDescription2 as XInterfaceAttributeTypeDescription2
from ...lo.reflection.x_interface_member_type_description import XInterfaceMemberTypeDescription as XInterfaceMemberTypeDescription
from ...lo.reflection.x_interface_method_type_description import XInterfaceMethodTypeDescription as XInterfaceMethodTypeDescription
from ...lo.reflection.x_interface_type_description import XInterfaceTypeDescription as XInterfaceTypeDescription
from ...lo.reflection.x_interface_type_description2 import XInterfaceTypeDescription2 as XInterfaceTypeDescription2
from ...lo.reflection.x_method_parameter import XMethodParameter as XMethodParameter
from ...lo.reflection.x_module_type_description import XModuleTypeDescription as XModuleTypeDescription
from ...lo.reflection.x_parameter import XParameter as XParameter
from ...lo.reflection.x_property_type_description import XPropertyTypeDescription as XPropertyTypeDescription
from ...lo.reflection.x_proxy_factory import XProxyFactory as XProxyFactory
from ...lo.reflection.x_published import XPublished as XPublished
from ...lo.reflection.x_service_constructor_description import XServiceConstructorDescription as XServiceConstructorDescription
from ...lo.reflection.x_service_type_description import XServiceTypeDescription as XServiceTypeDescription
from ...lo.reflection.x_service_type_description2 import XServiceTypeDescription2 as XServiceTypeDescription2
from ...lo.reflection.x_singleton_type_description import XSingletonTypeDescription as XSingletonTypeDescription
from ...lo.reflection.x_singleton_type_description2 import XSingletonTypeDescription2 as XSingletonTypeDescription2
from ...lo.reflection.x_struct_type_description import XStructTypeDescription as XStructTypeDescription
from ...lo.reflection.x_type_description import XTypeDescription as XTypeDescription
from ...lo.reflection.x_type_description_enumeration import XTypeDescriptionEnumeration as XTypeDescriptionEnumeration
from ...lo.reflection.x_type_description_enumeration_access import XTypeDescriptionEnumerationAccess as XTypeDescriptionEnumerationAccess
from ...lo.reflection.x_union_type_description import XUnionTypeDescription as XUnionTypeDescription
from ...lo.reflection.the_core_reflection import theCoreReflection as theCoreReflection



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XLinguProperties(XPropertySet_bc180bfa):
    """
    Interface for LinguProperties service.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XLinguProperties <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XLinguProperties'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XLinguProperties'

    @abstractproperty
    def DefaultLocale(self) -> Locale_70d308fa:
        """
        the default western language for new documents.
        """
        ...

    @abstractproperty
    def DefaultLocale_CJK(self) -> Locale_70d308fa:
        """
        the default language for CJK languages.
        """
        ...

    @abstractproperty
    def DefaultLocale_CTL(self) -> Locale_70d308fa:
        """
        the default language for CTL languages.
        """
        ...

    @abstractproperty
    def HyphMinLeading(self) -> int:
        """
        the minimum number of characters of a word to remain before the hyphen when doing hyphenation.
        """
        ...

    @abstractproperty
    def HyphMinTrailing(self) -> int:
        """
        the minimum number of characters of a word to remain after the hyphen when doing hyphenation.
        """
        ...

    @abstractproperty
    def HyphMinWordLength(self) -> int:
        """
        the minimum length of a word in order to be hyphenated.
        """
        ...

    @abstractproperty
    def IsHyphAuto(self) -> bool:
        """
        defines whether interactive hyphenation should be performed without requiring the user to select every hyphenation position after the user has triggered the hyphenation.
        """
        ...

    @abstractproperty
    def IsHyphSpecial(self) -> bool:
        """
        defines whether hyphenation should be done in special regions of documents or not.
        """
        ...

    @abstractproperty
    def IsIgnoreControlCharacters(self) -> bool:
        """
        defines if control characters should be ignored or not, by the linguistic (i.e., spell checker, hyphenator and thesaurus).
        """
        ...

    @abstractproperty
    def IsSpellAuto(self) -> bool:
        """
        indicates whether spell checking should be done automatically or not.
        """
        ...

    @abstractproperty
    def IsSpellCapitalization(self) -> bool:
        """
        defines if the capitalization of words should be checked or not.
        """
        ...

    @abstractproperty
    def IsSpellSpecial(self) -> bool:
        """
        defines whether spell checking should be done in special regions of documents or not.
        """
        ...

    @abstractproperty
    def IsSpellUpperCase(self) -> bool:
        """
        defines if words with only uppercase letters should be subject to spell checking or not.
        """
        ...

    @abstractproperty
    def IsSpellWithDigits(self) -> bool:
        """
        defines if words containing digits (or numbers) should be subject to spell checking or not.
        """
        ...

    @abstractproperty
    def IsUseDictionaryList(self) -> bool:
        """
        defines if the dictionary-list should be used for spell checking and hyphenation or not.
        """
        ...

    @abstractproperty
    def IsWrapReverse(self) -> bool:
        """
        defines whether spell checking should be done in reverse direction or not.
        """
        ...


__all__ = ['XLinguProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class Border(metaclass=UnoEnumMeta, type_name="com.sun.star.sheet.Border", name_space="com.sun.star.sheet"):
        """Dynamically created class that represents ``com.sun.star.sheet.Border`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.sheet.Border import BOTTOM as BORDER_BOTTOM
        from com.sun.star.sheet.Border import LEFT as BORDER_LEFT
        from com.sun.star.sheet.Border import RIGHT as BORDER_RIGHT
        from com.sun.star.sheet.Border import TOP as BORDER_TOP

        class Border(uno.Enum):
            """
            Enum Class


            See Also:
                `API Border <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#aea307cd05a4c363d9cac3828a62f4127>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.sheet.Border', value)

            __ooo_ns__: str = 'com.sun.star.sheet'
            __ooo_full_ns__: str = 'com.sun.star.sheet.Border'
            __ooo_type_name__: str = 'enum'

            BOTTOM = BORDER_BOTTOM
            """
            selects the bottom border.
            """
            LEFT = BORDER_LEFT
            """
            selects the left border.

            the cells to the right of the deleted cells are moved left.
            """
            RIGHT = BORDER_RIGHT
            """
            selects the right border.

            the cells to the right of the inserted cells are moved right.
            """
            TOP = BORDER_TOP
            """
            selects the top border.
            """
    else:
        # keep document generators happy
        from ...lo.sheet.border import Border as Border


__all__ = ['Border']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.i18n.TransliterationModules import TransliterationModulesProto

class TransliterationModules(Enum):
    """
    Enum Class


    See Also:
        `API TransliterationModules <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a9c57a33dd757352c82923f4c7f6cf93c>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModules'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.i18n.TransliterationModules'

    END_OF_MODULE = cast("TransliterationModulesProto", 'END_OF_MODULE')
    """
    """
    FULLWIDTH_HALFWIDTH = cast("TransliterationModulesProto", 'FULLWIDTH_HALFWIDTH')
    """
    Transliterate a string from full width character to half width character.
    """
    HALFWIDTH_FULLWIDTH = cast("TransliterationModulesProto", 'HALFWIDTH_FULLWIDTH')
    """
    Transliterate a string from half width character to full width character.
    """
    HIRAGANA_KATAKANA = cast("TransliterationModulesProto", 'HIRAGANA_KATAKANA')
    """
    Transliterate a Japanese string from Hiragana to Katakana.
    """
    IGNORE_CASE = cast("TransliterationModulesProto", 'IGNORE_CASE')
    """
    Ignore case when comparing strings by transliteration service.
    """
    IGNORE_KANA = cast("TransliterationModulesProto", 'IGNORE_KANA')
    """
    Ignore Hiragana and Katakana when comparing strings by transliteration service.
    """
    IGNORE_MASK = cast("TransliterationModulesProto", 'IGNORE_MASK')
    """
    """
    IGNORE_WIDTH = cast("TransliterationModulesProto", 'IGNORE_WIDTH')
    """
    Ignore full width and half width character when comparing strings by transliteration service.
    
    Ignore full width and half width characters when comparing strings by transliteration service.
    """
    IgnoreBaFa_ja_JP = cast("TransliterationModulesProto", 'IgnoreBaFa_ja_JP')
    """
    Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
    """
    IgnoreHyuByu_ja_JP = cast("TransliterationModulesProto", 'IgnoreHyuByu_ja_JP')
    """
    Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
    """
    IgnoreIandEfollowedByYa_ja_JP = cast("TransliterationModulesProto", 'IgnoreIandEfollowedByYa_ja_JP')
    """
    Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.
    
    Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
    """
    IgnoreIterationMark_ja_JP = cast("TransliterationModulesProto", 'IgnoreIterationMark_ja_JP')
    """
    Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
    """
    IgnoreKiKuFollowedBySa_ja_JP = cast("TransliterationModulesProto", 'IgnoreKiKuFollowedBySa_ja_JP')
    """
    Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.
    
    Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
    """
    IgnoreMiddleDot_ja_JP = cast("TransliterationModulesProto", 'IgnoreMiddleDot_ja_JP')
    """
    Ignore middle dot in Japanese fuzzy search.
    """
    IgnoreMinusSign_ja_JP = cast("TransliterationModulesProto", 'IgnoreMinusSign_ja_JP')
    """
    Ignore dash or minus sign in Japanese fuzzy search.
    """
    IgnoreProlongedSoundMark_ja_JP = cast("TransliterationModulesProto", 'IgnoreProlongedSoundMark_ja_JP')
    """
    Ignore Japanese prolonged sound mark in Japanese fuzzy search.
    """
    IgnoreSeZe_ja_JP = cast("TransliterationModulesProto", 'IgnoreSeZe_ja_JP')
    """
    Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
    """
    IgnoreSeparator_ja_JP = cast("TransliterationModulesProto", 'IgnoreSeparator_ja_JP')
    """
    Ignore separator punctuations in Japanese fuzzy search.
    """
    IgnoreSize_ja_JP = cast("TransliterationModulesProto", 'IgnoreSize_ja_JP')
    """
    Ignore Japanese normal and small sized character in Japanese fuzzy search.
    """
    IgnoreSpace_ja_JP = cast("TransliterationModulesProto", 'IgnoreSpace_ja_JP')
    """
    Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
    """
    IgnoreTiJi_ja_JP = cast("TransliterationModulesProto", 'IgnoreTiJi_ja_JP')
    """
    Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
    """
    IgnoreTraditionalKana_ja_JP = cast("TransliterationModulesProto", 'IgnoreTraditionalKana_ja_JP')
    """
    Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.
    
    Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
    """
    IgnoreTraditionalKanji_ja_JP = cast("TransliterationModulesProto", 'IgnoreTraditionalKanji_ja_JP')
    """
    Ignore Japanese traditional Kanji character in Japanese fuzzy search.
    
    Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
    """
    IgnoreZiZu_ja_JP = cast("TransliterationModulesProto", 'IgnoreZiZu_ja_JP')
    """
    Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
    """
    KATAKANA_HIRAGANA = cast("TransliterationModulesProto", 'KATAKANA_HIRAGANA')
    """
    Transliterate a Japanese string from Katakana to Hiragana.
    """
    LOWERCASE_UPPERCASE = cast("TransliterationModulesProto", 'LOWERCASE_UPPERCASE')
    """
    Transliterate a string from lower case to upper case.
    """
    LargeToSmall_ja_JP = cast("TransliterationModulesProto", 'LargeToSmall_ja_JP')
    """
    transliterate Japanese normal sized character to small sized character
    """
    NON_IGNORE_MASK = cast("TransliterationModulesProto", 'NON_IGNORE_MASK')
    """
    """
    NumToTextFormalHangul_ko = cast("TransliterationModulesProto", 'NumToTextFormalHangul_ko')
    """
    Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
    """
    NumToTextFormalLower_ko = cast("TransliterationModulesProto", 'NumToTextFormalLower_ko')
    """
    Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
    """
    NumToTextFormalUpper_ko = cast("TransliterationModulesProto", 'NumToTextFormalUpper_ko')
    """
    Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
    """
    NumToTextLower_zh_CN = cast("TransliterationModulesProto", 'NumToTextLower_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
    """
    NumToTextLower_zh_TW = cast("TransliterationModulesProto", 'NumToTextLower_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
    """
    NumToTextUpper_zh_CN = cast("TransliterationModulesProto", 'NumToTextUpper_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
    """
    NumToTextUpper_zh_TW = cast("TransliterationModulesProto", 'NumToTextUpper_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
    """
    SmallToLarge_ja_JP = cast("TransliterationModulesProto", 'SmallToLarge_ja_JP')
    """
    transliterate Japanese small sized character to normal sized character
    """
    UPPERCASE_LOWERCASE = cast("TransliterationModulesProto", 'UPPERCASE_LOWERCASE')
    """
    Transliterate a string from upper case to lower case.
    """

__all__ = ['TransliterationModules']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.size import Size as Size_576707ef

class XChartShape(XInterface_8f010a43):
    """
    this interface is used for a wrapper of objects implementing the service com.sun.star.drawing.Shape

    See Also:
        `API XChartShape <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XChartShape'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XChartShape'

    @abstractmethod
    def getPosition(self) -> Point_5fb2085e:
        """
        the method corresponds to the identical methods of the interface com.sun.star.drawing.XShape
        """
        ...
    @abstractmethod
    def getPropertyValue(self, PropertyName: str) -> object:
        """
        the method corresponds to the identical methods of the interface com.sun.star.beans.XPropertySet

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getShapeType(self) -> str:
        """
        the method corresponds to the identical methods of the interface com.sun.star.drawing.XShape ??????????? deprecated
        """
        ...
    @abstractmethod
    def getSize(self) -> Size_576707ef:
        """
        the method corresponds to the identical methods of the interface com.sun.star.drawing.XShape
        """
        ...
    @abstractmethod
    def setPosition(self, aPosition: Point_5fb2085e) -> None:
        """
        the method corresponds to the identical methods of the interface com.sun.star.drawing.XShape
        """
        ...
    @abstractmethod
    def setPropertyValue(self, aPropertyName: str, aValue: object) -> None:
        """
        the method corresponds to the identical methods of the interface com.sun.star.beans.XPropertySet

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def setSize(self, aSize: Size_576707ef) -> None:
        """
        the method corresponds to the identical methods of the interface com.sun.star.drawing.XShape

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
        """
        ...

__all__ = ['XChartShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TableBorderDistances(object):
    """
    Struct Class

    contains the distance settings of the border lines of all cells in a cell range.
    
    In a queried structure, the flags in TableBorderDistances.Is...DistanceValid indicate that not all lines of the boxes have the same values.
    
    In a structure which is used for setting, these flags determine if the corresponding distance should be set or if the old value should be kept.

    See Also:
        `API TableBorderDistances <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1TableBorderDistances.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.TableBorderDistances'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.TableBorderDistances'
    """Literal Constant ``com.sun.star.table.TableBorderDistances``"""

    def __init__(self, TopDistance: typing.Optional[int] = 0, IsTopDistanceValid: typing.Optional[bool] = False, BottomDistance: typing.Optional[int] = 0, IsBottomDistanceValid: typing.Optional[bool] = False, LeftDistance: typing.Optional[int] = 0, IsLeftDistanceValid: typing.Optional[bool] = False, RightDistance: typing.Optional[int] = 0, IsRightDistanceValid: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            TopDistance (int, optional): TopDistance value.
            IsTopDistanceValid (bool, optional): IsTopDistanceValid value.
            BottomDistance (int, optional): BottomDistance value.
            IsBottomDistanceValid (bool, optional): IsBottomDistanceValid value.
            LeftDistance (int, optional): LeftDistance value.
            IsLeftDistanceValid (bool, optional): IsLeftDistanceValid value.
            RightDistance (int, optional): RightDistance value.
            IsRightDistanceValid (bool, optional): IsRightDistanceValid value.
        """
        super().__init__()

        if isinstance(TopDistance, TableBorderDistances):
            oth: TableBorderDistances = TopDistance
            self.TopDistance = oth.TopDistance
            self.IsTopDistanceValid = oth.IsTopDistanceValid
            self.BottomDistance = oth.BottomDistance
            self.IsBottomDistanceValid = oth.IsBottomDistanceValid
            self.LeftDistance = oth.LeftDistance
            self.IsLeftDistanceValid = oth.IsLeftDistanceValid
            self.RightDistance = oth.RightDistance
            self.IsRightDistanceValid = oth.IsRightDistanceValid
            return

        kargs = {
            "TopDistance": TopDistance,
            "IsTopDistanceValid": IsTopDistanceValid,
            "BottomDistance": BottomDistance,
            "IsBottomDistanceValid": IsBottomDistanceValid,
            "LeftDistance": LeftDistance,
            "IsLeftDistanceValid": IsLeftDistanceValid,
            "RightDistance": RightDistance,
            "IsRightDistanceValid": IsRightDistanceValid,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._top_distance = kwargs["TopDistance"]
        self._is_top_distance_valid = kwargs["IsTopDistanceValid"]
        self._bottom_distance = kwargs["BottomDistance"]
        self._is_bottom_distance_valid = kwargs["IsBottomDistanceValid"]
        self._left_distance = kwargs["LeftDistance"]
        self._is_left_distance_valid = kwargs["IsLeftDistanceValid"]
        self._right_distance = kwargs["RightDistance"]
        self._is_right_distance_valid = kwargs["IsRightDistanceValid"]


    @property
    def TopDistance(self) -> int:
        """
        contains the distance between the top lines and other contents.
        """
        return self._top_distance

    @TopDistance.setter
    def TopDistance(self, value: int) -> None:
        self._top_distance = value

    @property
    def IsTopDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.TopDistance is used.
        """
        return self._is_top_distance_valid

    @IsTopDistanceValid.setter
    def IsTopDistanceValid(self, value: bool) -> None:
        self._is_top_distance_valid = value

    @property
    def BottomDistance(self) -> int:
        """
        contains the distance between the bottom lines and other contents.
        """
        return self._bottom_distance

    @BottomDistance.setter
    def BottomDistance(self, value: int) -> None:
        self._bottom_distance = value

    @property
    def IsBottomDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.BottomDistance is used.
        """
        return self._is_bottom_distance_valid

    @IsBottomDistanceValid.setter
    def IsBottomDistanceValid(self, value: bool) -> None:
        self._is_bottom_distance_valid = value

    @property
    def LeftDistance(self) -> int:
        """
        contains the distance between the left lines and other contents.
        """
        return self._left_distance

    @LeftDistance.setter
    def LeftDistance(self, value: int) -> None:
        self._left_distance = value

    @property
    def IsLeftDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.LeftDistance is used.
        """
        return self._is_left_distance_valid

    @IsLeftDistanceValid.setter
    def IsLeftDistanceValid(self, value: bool) -> None:
        self._is_left_distance_valid = value

    @property
    def RightDistance(self) -> int:
        """
        contains the distance between the right lines and other contents.
        """
        return self._right_distance

    @RightDistance.setter
    def RightDistance(self, value: int) -> None:
        self._right_distance = value

    @property
    def IsRightDistanceValid(self) -> bool:
        """
        specifies whether the value of TableBorder.RightDistance is used.
        """
        return self._is_right_distance_valid

    @IsRightDistanceValid.setter
    def IsRightDistanceValid(self, value: bool) -> None:
        self._is_right_distance_valid = value


__all__ = ['TableBorderDistances']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_text_conversion import XTextConversion as XTextConversion_cd640c6b
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XExtendedTextConversion(XTextConversion_cd640c6b):
    """
    This interface provides Text Conversion service.
    
    It is derived from com.sun.star.i18n.XTextConversion and provides a new conversion function containing position map (offset) between original and converted string.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XExtendedTextConversion <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTextConversion.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XExtendedTextConversion'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XExtendedTextConversion'

    @abstractmethod
    def getConversionWithOffset(self, aText: str, nStartPos: int, nLength: int, aLocale: Locale_70d308fa, nTextConversionType: int, nTextConversionOptions: int, rOffset: uno.ByteSequence) -> str:
        """
        The functionality of this method is same as com.sun.star.i18n.XTextConversion.getConversion(), except an additional output parameter rOffset.

        * ``rOffset`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...

__all__ = ['XExtendedTextConversion']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from .x_append import XAppend as XAppend_847209cc
from .x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory_46170fe5
from .x_drop import XDrop as XDrop_71590909
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class Container(XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNameAccess_e2ab0cf6, XAppend_847209cc, XDataDescriptorFactory_46170fe5, XDrop_71590909, XRefreshable_b0d60b81):
    """
    Service Class

    describes every container which is used for data definition.
    
    Each container must support access to its elements by the element's name or by the element's position.
    
    Simple enumeration must be supported as well.
    
    To reflect the changes with the underlying database, a refresh mechanism needs to be supported.
    
    A container may support the possibility to add new elements or to drop existing elements. Additions are always done by descriptors which define the properties of the new element.

    See Also:
        `API Container <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Container.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Container'
    __ooo_type_name__: str = 'service'


__all__ = ['Container']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor_47cc0ff7
from .x_sheet_filter_descriptor2 import XSheetFilterDescriptor2 as XSheetFilterDescriptor2_57f51029
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from com.sun.star.table.TableOrientation import TableOrientationProto

class SheetFilterDescriptor(XPropertySet_bc180bfa, XSheetFilterDescriptor2_57f51029, XSheetFilterDescriptor_47cc0ff7):
    """
    Service Class

    represents a description of how a cell range is to be filtered.
    
    The descriptor contains properties and a collection of filter conditions (filter fields) which control the behavior of a filter operation.
    
    **since**
    
        OOo 3.2

    See Also:
        `API SheetFilterDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetFilterDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetFilterDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ContainsHeader(self) -> bool:
        """
        specifies if the first row (or column) contains headers which should not be filtered.
        """
        ...

    @abstractproperty
    def CopyOutputData(self) -> bool:
        """
        specifies if the filtered data should be copied to another position in the document.
        """
        ...

    @abstractproperty
    def IsCaseSensitive(self) -> bool:
        """
        specifies if the case of letters is important when comparing entries.
        """
        ...

    @abstractproperty
    def MaxFieldCount(self) -> int:
        """
        returns the maximum number of filter fields in the descriptor.
        
        This read-only property indicates the maximum count of fields the current implementation supports.
        """
        ...

    @abstractproperty
    def Orientation(self) -> TableOrientationProto:
        """
        specifies if columns or rows are filtered.
        """
        ...

    @abstractproperty
    def OutputPosition(self) -> CellAddress_ae5f0b56:
        """
        specifies the position where filtered data are to be copied.
        
        This is only used if SheetFilterDescriptor.CopyOutputData is TRUE.
        """
        ...

    @abstractproperty
    def SaveOutputPosition(self) -> bool:
        """
        specifies if the SheetFilterDescriptor.OutputPosition position is saved for future calls.
        
        This is only used if SheetFilterDescriptor.CopyOutputData is TRUE.
        """
        ...

    @abstractproperty
    def SkipDuplicates(self) -> bool:
        """
        specifies if duplicate entries are left out of the result.
        """
        ...

    @abstractproperty
    def UseRegularExpressions(self) -> bool:
        """
        specifies if the TableFilterField.StringValue strings are interpreted as regular expressions.
        """
        ...


__all__ = ['SheetFilterDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class EscapeDirection(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.EscapeDirection", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.EscapeDirection`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.EscapeDirection import DOWN as ESCAPE_DIRECTION_DOWN
        from com.sun.star.drawing.EscapeDirection import HORIZONTAL as ESCAPE_DIRECTION_HORIZONTAL
        from com.sun.star.drawing.EscapeDirection import LEFT as ESCAPE_DIRECTION_LEFT
        from com.sun.star.drawing.EscapeDirection import RIGHT as ESCAPE_DIRECTION_RIGHT
        from com.sun.star.drawing.EscapeDirection import SMART as ESCAPE_DIRECTION_SMART
        from com.sun.star.drawing.EscapeDirection import UP as ESCAPE_DIRECTION_UP
        from com.sun.star.drawing.EscapeDirection import VERTICAL as ESCAPE_DIRECTION_VERTICAL

        class EscapeDirection(uno.Enum):
            """
            Enum Class


            See Also:
                `API EscapeDirection <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a554864869ec34ebdfb5ecde01c5c5670>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.EscapeDirection', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.EscapeDirection'
            __ooo_type_name__: str = 'enum'

            DOWN = ESCAPE_DIRECTION_DOWN
            """
            """
            HORIZONTAL = ESCAPE_DIRECTION_HORIZONTAL
            """
            mirror to the horizontal axis
            """
            LEFT = ESCAPE_DIRECTION_LEFT
            """
            the connection line leaves the connected object to the left,

            The left edge of the text is adjusted to the left edge of the shape.

            The text is positioned to the left.
            """
            RIGHT = ESCAPE_DIRECTION_RIGHT
            """
            the connection line leaves the connected object to the right,

            The right edge of the text is adjusted to the right edge of the shape.

            The text is positioned to the right.
            """
            SMART = ESCAPE_DIRECTION_SMART
            """
            """
            UP = ESCAPE_DIRECTION_UP
            """
            """
            VERTICAL = ESCAPE_DIRECTION_VERTICAL
            """
            mirror to the vertical axis
            """
    else:
        # keep document generators happy
        from ...lo.drawing.escape_direction import EscapeDirection as EscapeDirection


__all__ = ['EscapeDirection']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.inspection
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class PropertyCategoryDescriptor(object):
    """
    Struct Class

    describes a category of properties
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API PropertyCategoryDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1inspection_1_1PropertyCategoryDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.PropertyCategoryDescriptor'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.inspection.PropertyCategoryDescriptor'
    """Literal Constant ``com.sun.star.inspection.PropertyCategoryDescriptor``"""

    def __init__(self, ProgrammaticName: typing.Optional[str] = '', UIName: typing.Optional[str] = '', HelpURL: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            ProgrammaticName (str, optional): ProgrammaticName value.
            UIName (str, optional): UIName value.
            HelpURL (str, optional): HelpURL value.
        """
        super().__init__()

        if isinstance(ProgrammaticName, PropertyCategoryDescriptor):
            oth: PropertyCategoryDescriptor = ProgrammaticName
            self.ProgrammaticName = oth.ProgrammaticName
            self.UIName = oth.UIName
            self.HelpURL = oth.HelpURL
            return

        kargs = {
            "ProgrammaticName": ProgrammaticName,
            "UIName": UIName,
            "HelpURL": HelpURL,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._programmatic_name = kwargs["ProgrammaticName"]
        self._ui_name = kwargs["UIName"]
        self._help_url = kwargs["HelpURL"]


    @property
    def ProgrammaticName(self) -> str:
        """
        contains the programmatic name of the category.
        
        This programmatic name is used internally: XPropertyHandler.describePropertyLine() sets a programmatic category name at LineDescriptor.Category, and an object inspector uses this to find the proper PropertyCategoryDescriptor.
        """
        return self._programmatic_name

    @ProgrammaticName.setter
    def ProgrammaticName(self, value: str) -> None:
        self._programmatic_name = value

    @property
    def UIName(self) -> str:
        """
        provides a human-readable name (which can be presented at the UI) for a category.
        """
        return self._ui_name

    @UIName.setter
    def UIName(self, value: str) -> None:
        self._ui_name = value

    @property
    def HelpURL(self) -> str:
        """
        provides a help URL to be associated with a category
        """
        return self._help_url

    @HelpURL.setter
    def HelpURL(self, value: str) -> None:
        self._help_url = value


__all__ = ['PropertyCategoryDescriptor']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractmethod
from .x_text_content import XTextContent as XTextContent_b16e0ba5

class XDocumentIndexMark(XTextContent_b16e0ba5):
    """
    gives access to the mark of a document index entry.

    See Also:
        `API XDocumentIndexMark <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndexMark.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XDocumentIndexMark'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XDocumentIndexMark'

    @abstractmethod
    def getMarkEntry(self) -> str:
        """
        """
        ...
    @abstractmethod
    def setMarkEntry(self, aIndexEntry: str) -> None:
        """
        sets an explicit string for this index mark to use in the index.
        
        If empty, the string of the TextRange to which the TextContent refers is used in the index.
        """
        ...

__all__ = ['XDocumentIndexMark']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from ..frame.x_model import XModel as XModel_7a6e095c


class MailMergeEvent(EventObject_a3d70b03):
    """
    Struct Class

    represents a mail merge event.
    
    This type of event is being sent by the mail merge service right before the merging of the next document to be processed. This allows for example to modify the document specifically before it gets merged.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API MailMergeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1MailMergeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.MailMergeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.MailMergeEvent'
    """Literal Constant ``com.sun.star.text.MailMergeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Model: typing.Optional[XModel_7a6e095c] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Model (XModel, optional): Model value.
        """

        if isinstance(Source, MailMergeEvent):
            oth: MailMergeEvent = Source
            self.Source = oth.Source
            self.Model = oth.Model
            return

        kargs = {
            "Source": Source,
            "Model": Model,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._model = kwargs["Model"]
        inst_keys = ('Model',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Model(self) -> XModel_7a6e095c:
        """
        The model of the document to be processed next.
        """
        return self._model

    @Model.setter
    def Model(self, value: XModel_7a6e095c) -> None:
        self._model = value


__all__ = ['MailMergeEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .single_reference import SingleReference as SingleReference_e27e0d12


class ComplexReference(object):
    """
    Struct Class

    contains a reference to a cell range.

    See Also:
        `API ComplexReference <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1ComplexReference.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.ComplexReference'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.ComplexReference'
    """Literal Constant ``com.sun.star.sheet.ComplexReference``"""

    def __init__(self, Reference1: typing.Optional[SingleReference_e27e0d12] = UNO_NONE, Reference2: typing.Optional[SingleReference_e27e0d12] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            Reference1 (SingleReference, optional): Reference1 value.
            Reference2 (SingleReference, optional): Reference2 value.
        """
        super().__init__()

        if isinstance(Reference1, ComplexReference):
            oth: ComplexReference = Reference1
            self.Reference1 = oth.Reference1
            self.Reference2 = oth.Reference2
            return

        kargs = {
            "Reference1": Reference1,
            "Reference2": Reference2,
        }
        if kargs["Reference1"] is UNO_NONE:
            kargs["Reference1"] = None
        if kargs["Reference2"] is UNO_NONE:
            kargs["Reference2"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._reference1 = kwargs["Reference1"]
        self._reference2 = kwargs["Reference2"]


    @property
    def Reference1(self) -> SingleReference_e27e0d12:
        """
        is the first reference.
        """
        return self._reference1

    @Reference1.setter
    def Reference1(self, value: SingleReference_e27e0d12) -> None:
        self._reference1 = value

    @property
    def Reference2(self) -> SingleReference_e27e0d12:
        """
        is the second reference.
        """
        return self._reference2

    @Reference2.setter
    def Reference2(self, value: SingleReference_e27e0d12) -> None:
        self._reference2 = value


__all__ = ['ComplexReference']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class PropertyState(metaclass=UnoEnumMeta, type_name="com.sun.star.beans.PropertyState", name_space="com.sun.star.beans"):
        """Dynamically created class that represents ``com.sun.star.beans.PropertyState`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.beans.PropertyState import AMBIGUOUS_VALUE as PROPERTY_STATE_AMBIGUOUS_VALUE
        from com.sun.star.beans.PropertyState import DEFAULT_VALUE as PROPERTY_STATE_DEFAULT_VALUE
        from com.sun.star.beans.PropertyState import DIRECT_VALUE as PROPERTY_STATE_DIRECT_VALUE

        class PropertyState(uno.Enum):
            """
            Enum Class


            See Also:
                `API PropertyState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans.html#a1a5ccb5c59cace4a214c1e2eae8620b0>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.beans.PropertyState', value)

            __ooo_ns__: str = 'com.sun.star.beans'
            __ooo_full_ns__: str = 'com.sun.star.beans.PropertyState'
            __ooo_type_name__: str = 'enum'

            AMBIGUOUS_VALUE = PROPERTY_STATE_AMBIGUOUS_VALUE
            """
            The value of the property is only a recommendation because there are multiple values for this property (e.g., from a multi selection).

            The PropertyAttribute field in the struct Property must contain the PropertyAttribute.MAYBEAMBIGUOUS flag. The property value must be available and of the specified type. If the Attribute field in the struct Property contains PropertyAttribute.MAYBEVOID, then the value may be void.
            """
            DEFAULT_VALUE = PROPERTY_STATE_DEFAULT_VALUE
            """
            The value of the property is available from a master (e.g., template).
            """
            DIRECT_VALUE = PROPERTY_STATE_DIRECT_VALUE
            """
            The value of the property is stored in the PropertySet itself.
            """
    else:
        # keep document generators happy
        from ...lo.beans.property_state import PropertyState as PropertyState


__all__ = ['PropertyState']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.drawing.accessible_draw_document_view import AccessibleDrawDocumentView as AccessibleDrawDocumentView
with suppress(ImportError):
    from ...dyn.drawing.accessible_graph_control import AccessibleGraphControl as AccessibleGraphControl
with suppress(ImportError):
    from ...dyn.drawing.accessible_graphic_shape import AccessibleGraphicShape as AccessibleGraphicShape
with suppress(ImportError):
    from ...dyn.drawing.accessible_image_bullet import AccessibleImageBullet as AccessibleImageBullet
with suppress(ImportError):
    from ...dyn.drawing.accessible_ole_shape import AccessibleOLEShape as AccessibleOLEShape
with suppress(ImportError):
    from ...dyn.drawing.accessible_shape import AccessibleShape as AccessibleShape
with suppress(ImportError):
    from ...dyn.drawing.accessible_slide_view import AccessibleSlideView as AccessibleSlideView
with suppress(ImportError):
    from ...dyn.drawing.accessible_slide_view_object import AccessibleSlideViewObject as AccessibleSlideViewObject
with suppress(ImportError):
    from ...dyn.drawing.alignment import Alignment as Alignment
with suppress(ImportError):
    from ...dyn.drawing.applet_shape import AppletShape as AppletShape
with suppress(ImportError):
    from ...dyn.drawing.arrangement import Arrangement as Arrangement
with suppress(ImportError):
    from ...dyn.drawing.background import Background as Background
with suppress(ImportError):
    from ...dyn.drawing.bar_code import BarCode as BarCode
with suppress(ImportError):
    from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrection as BarCodeErrorCorrection
with suppress(ImportError):
    from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrectionEnum as BarCodeErrorCorrectionEnum
with suppress(ImportError):
    from ...dyn.drawing.bezier_point import BezierPoint as BezierPoint
with suppress(ImportError):
    from ...dyn.drawing.bitmap_mode import BitmapMode as BitmapMode
with suppress(ImportError):
    from ...dyn.drawing.bitmap_table import BitmapTable as BitmapTable
with suppress(ImportError):
    from ...dyn.drawing.bound_volume import BoundVolume as BoundVolume
with suppress(ImportError):
    from ...dyn.drawing.camera_geometry import CameraGeometry as CameraGeometry
with suppress(ImportError):
    from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirection as CaptionEscapeDirection
with suppress(ImportError):
    from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirectionEnum as CaptionEscapeDirectionEnum
with suppress(ImportError):
    from ...dyn.drawing.caption_shape import CaptionShape as CaptionShape
with suppress(ImportError):
    from ...dyn.drawing.caption_type import CaptionType as CaptionType
with suppress(ImportError):
    from ...dyn.drawing.caption_type import CaptionTypeEnum as CaptionTypeEnum
with suppress(ImportError):
    from ...dyn.drawing.circle_kind import CircleKind as CircleKind
with suppress(ImportError):
    from ...dyn.drawing.closed_bezier_shape import ClosedBezierShape as ClosedBezierShape
with suppress(ImportError):
    from ...dyn.drawing.color_mode import ColorMode as ColorMode
with suppress(ImportError):
    from ...dyn.drawing.color_table import ColorTable as ColorTable
with suppress(ImportError):
    from ...dyn.drawing.connection_type import ConnectionType as ConnectionType
with suppress(ImportError):
    from ...dyn.drawing.connector_properties import ConnectorProperties as ConnectorProperties
with suppress(ImportError):
    from ...dyn.drawing.connector_shape import ConnectorShape as ConnectorShape
with suppress(ImportError):
    from ...dyn.drawing.connector_type import ConnectorType as ConnectorType
with suppress(ImportError):
    from ...dyn.drawing.control_shape import ControlShape as ControlShape
with suppress(ImportError):
    from ...dyn.drawing.coordinate_sequence import CoordinateSequence as CoordinateSequence
with suppress(ImportError):
    from ...dyn.drawing.coordinate_sequence_sequence import CoordinateSequenceSequence as CoordinateSequenceSequence
with suppress(ImportError):
    from ...dyn.drawing.custom_shape import CustomShape as CustomShape
with suppress(ImportError):
    from ...dyn.drawing.custom_shape_engine import CustomShapeEngine as CustomShapeEngine
with suppress(ImportError):
    from ...dyn.drawing.dash_style import DashStyle as DashStyle
with suppress(ImportError):
    from ...dyn.drawing.dash_table import DashTable as DashTable
with suppress(ImportError):
    from ...dyn.drawing.defaults import Defaults as Defaults
with suppress(ImportError):
    from ...dyn.drawing.direction3_d import Direction3D as Direction3D
with suppress(ImportError):
    from ...dyn.drawing.document_settings import DocumentSettings as DocumentSettings
with suppress(ImportError):
    from ...dyn.drawing.double_sequence import DoubleSequence as DoubleSequence
with suppress(ImportError):
    from ...dyn.drawing.double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence
with suppress(ImportError):
    from ...dyn.drawing.draw_page import DrawPage as DrawPage
with suppress(ImportError):
    from ...dyn.drawing.draw_pages import DrawPages as DrawPages
with suppress(ImportError):
    from ...dyn.drawing.draw_view_mode import DrawViewMode as DrawViewMode
with suppress(ImportError):
    from ...dyn.drawing.drawing_document import DrawingDocument as DrawingDocument
with suppress(ImportError):
    from ...dyn.drawing.drawing_document_draw_view import DrawingDocumentDrawView as DrawingDocumentDrawView
with suppress(ImportError):
    from ...dyn.drawing.drawing_document_factory import DrawingDocumentFactory as DrawingDocumentFactory
with suppress(ImportError):
    from ...dyn.drawing.ellipse_shape import EllipseShape as EllipseShape
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_extrusion import EnhancedCustomShapeExtrusion as EnhancedCustomShapeExtrusion
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_geometry import EnhancedCustomShapeGeometry as EnhancedCustomShapeGeometry
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointType as EnhancedCustomShapeGluePointType
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointTypeEnum as EnhancedCustomShapeGluePointTypeEnum
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_handle import EnhancedCustomShapeHandle as EnhancedCustomShapeHandle
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_metal_type import EnhancedCustomShapeMetalType as EnhancedCustomShapeMetalType
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_metal_type import EnhancedCustomShapeMetalTypeEnum as EnhancedCustomShapeMetalTypeEnum
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterType as EnhancedCustomShapeParameterType
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterTypeEnum as EnhancedCustomShapeParameterTypeEnum
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_path import EnhancedCustomShapePath as EnhancedCustomShapePath
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommand as EnhancedCustomShapeSegmentCommand
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommandEnum as EnhancedCustomShapeSegmentCommandEnum
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_text_path import EnhancedCustomShapeTextPath as EnhancedCustomShapeTextPath
with suppress(ImportError):
    from ...dyn.drawing.enhanced_custom_shape_text_path_mode import EnhancedCustomShapeTextPathMode as EnhancedCustomShapeTextPathMode
with suppress(ImportError):
    from ...dyn.drawing.escape_direction import EscapeDirection as EscapeDirection
with suppress(ImportError):
    from ...dyn.drawing.fill_properties import FillProperties as FillProperties
with suppress(ImportError):
    from ...dyn.drawing.fill_style import FillStyle as FillStyle
with suppress(ImportError):
    from ...dyn.drawing.flag_sequence import FlagSequence as FlagSequence
with suppress(ImportError):
    from ...dyn.drawing.flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence
with suppress(ImportError):
    from ...dyn.drawing.generic_draw_page import GenericDrawPage as GenericDrawPage
with suppress(ImportError):
    from ...dyn.drawing.generic_drawing_document import GenericDrawingDocument as GenericDrawingDocument
with suppress(ImportError):
    from ...dyn.drawing.glue_point import GluePoint as GluePoint
with suppress(ImportError):
    from ...dyn.drawing.glue_point2 import GluePoint2 as GluePoint2
with suppress(ImportError):
    from ...dyn.drawing.gradient_table import GradientTable as GradientTable
with suppress(ImportError):
    from ...dyn.drawing.graphic_export_filter import GraphicExportFilter as GraphicExportFilter
with suppress(ImportError):
    from ...dyn.drawing.graphic_filter_request import GraphicFilterRequest as GraphicFilterRequest
with suppress(ImportError):
    from ...dyn.drawing.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
with suppress(ImportError):
    from ...dyn.drawing.group_shape import GroupShape as GroupShape
with suppress(ImportError):
    from ...dyn.drawing.hatch import Hatch as Hatch
with suppress(ImportError):
    from ...dyn.drawing.hatch_style import HatchStyle as HatchStyle
with suppress(ImportError):
    from ...dyn.drawing.hatch_table import HatchTable as HatchTable
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix import HomogenMatrix as HomogenMatrix
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix4 import HomogenMatrix4 as HomogenMatrix4
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix_line3 import HomogenMatrixLine3 as HomogenMatrixLine3
with suppress(ImportError):
    from ...dyn.drawing.homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4
with suppress(ImportError):
    from ...dyn.drawing.horizontal_dimensioning import HorizontalDimensioning as HorizontalDimensioning
with suppress(ImportError):
    from ...dyn.drawing.layer import Layer as Layer
with suppress(ImportError):
    from ...dyn.drawing.layer_manager import LayerManager as LayerManager
with suppress(ImportError):
    from ...dyn.drawing.layer_type import LayerType as LayerType
with suppress(ImportError):
    from ...dyn.drawing.line_cap import LineCap as LineCap
with suppress(ImportError):
    from ...dyn.drawing.line_dash import LineDash as LineDash
with suppress(ImportError):
    from ...dyn.drawing.line_end_type import LineEndType as LineEndType
with suppress(ImportError):
    from ...dyn.drawing.line_joint import LineJoint as LineJoint
with suppress(ImportError):
    from ...dyn.drawing.line_properties import LineProperties as LineProperties
with suppress(ImportError):
    from ...dyn.drawing.line_shape import LineShape as LineShape
with suppress(ImportError):
    from ...dyn.drawing.line_style import LineStyle as LineStyle
with suppress(ImportError):
    from ...dyn.drawing.marker_table import MarkerTable as MarkerTable
with suppress(ImportError):
    from ...dyn.drawing.master_page import MasterPage as MasterPage
with suppress(ImportError):
    from ...dyn.drawing.master_pages import MasterPages as MasterPages
with suppress(ImportError):
    from ...dyn.drawing.measure_kind import MeasureKind as MeasureKind
with suppress(ImportError):
    from ...dyn.drawing.measure_properties import MeasureProperties as MeasureProperties
with suppress(ImportError):
    from ...dyn.drawing.measure_shape import MeasureShape as MeasureShape
with suppress(ImportError):
    from ...dyn.drawing.measure_text_horz_pos import MeasureTextHorzPos as MeasureTextHorzPos
with suppress(ImportError):
    from ...dyn.drawing.measure_text_vert_pos import MeasureTextVertPos as MeasureTextVertPos
with suppress(ImportError):
    from ...dyn.drawing.mirror_axis import MirrorAxis as MirrorAxis
with suppress(ImportError):
    from ...dyn.drawing.module_dispatcher import ModuleDispatcher as ModuleDispatcher
with suppress(ImportError):
    from ...dyn.drawing.normals_kind import NormalsKind as NormalsKind
with suppress(ImportError):
    from ...dyn.drawing.ole2_shape import OLE2Shape as OLE2Shape
with suppress(ImportError):
    from ...dyn.drawing.open_bezier_shape import OpenBezierShape as OpenBezierShape
with suppress(ImportError):
    from ...dyn.drawing.page_shape import PageShape as PageShape
with suppress(ImportError):
    from ...dyn.drawing.plugin_shape import PluginShape as PluginShape
with suppress(ImportError):
    from ...dyn.drawing.point_sequence import PointSequence as PointSequence
with suppress(ImportError):
    from ...dyn.drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence
with suppress(ImportError):
    from ...dyn.drawing.poly_line_shape import PolyLineShape as PolyLineShape
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_bezier_shape import PolyPolygonBezierShape as PolyPolygonBezierShape
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_descriptor import PolyPolygonDescriptor as PolyPolygonDescriptor
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_shape import PolyPolygonShape as PolyPolygonShape
with suppress(ImportError):
    from ...dyn.drawing.poly_polygon_shape3_d import PolyPolygonShape3D as PolyPolygonShape3D
with suppress(ImportError):
    from ...dyn.drawing.polygon_flags import PolygonFlags as PolygonFlags
with suppress(ImportError):
    from ...dyn.drawing.polygon_kind import PolygonKind as PolygonKind
with suppress(ImportError):
    from ...dyn.drawing.position3_d import Position3D as Position3D
with suppress(ImportError):
    from ...dyn.drawing.projection_mode import ProjectionMode as ProjectionMode
with suppress(ImportError):
    from ...dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
with suppress(ImportError):
    from ...dyn.drawing.rectangle_shape import RectangleShape as RectangleShape
with suppress(ImportError):
    from ...dyn.drawing.rotation_descriptor import RotationDescriptor as RotationDescriptor
with suppress(ImportError):
    from ...dyn.drawing.shade_mode import ShadeMode as ShadeMode
with suppress(ImportError):
    from ...dyn.drawing.shading_pattern import ShadingPattern as ShadingPattern
with suppress(ImportError):
    from ...dyn.drawing.shading_pattern import ShadingPatternEnum as ShadingPatternEnum
with suppress(ImportError):
    from ...dyn.drawing.shadow_properties import ShadowProperties as ShadowProperties
with suppress(ImportError):
    from ...dyn.drawing.shape import Shape as Shape
with suppress(ImportError):
    from ...dyn.drawing.shape_collection import ShapeCollection as ShapeCollection
with suppress(ImportError):
    from ...dyn.drawing.shapes import Shapes as Shapes
with suppress(ImportError):
    from ...dyn.drawing.slide_renderer import SlideRenderer as SlideRenderer
with suppress(ImportError):
    from ...dyn.drawing.slide_sorter import SlideSorter as SlideSorter
with suppress(ImportError):
    from ...dyn.drawing.snap_object_type import SnapObjectType as SnapObjectType
with suppress(ImportError):
    from ...dyn.drawing.text import Text as Text
with suppress(ImportError):
    from ...dyn.drawing.text_adjust import TextAdjust as TextAdjust
with suppress(ImportError):
    from ...dyn.drawing.text_animation_direction import TextAnimationDirection as TextAnimationDirection
with suppress(ImportError):
    from ...dyn.drawing.text_animation_kind import TextAnimationKind as TextAnimationKind
with suppress(ImportError):
    from ...dyn.drawing.text_fit_to_size_type import TextFitToSizeType as TextFitToSizeType
with suppress(ImportError):
    from ...dyn.drawing.text_horizontal_adjust import TextHorizontalAdjust as TextHorizontalAdjust
with suppress(ImportError):
    from ...dyn.drawing.text_properties import TextProperties as TextProperties
with suppress(ImportError):
    from ...dyn.drawing.text_shape import TextShape as TextShape
with suppress(ImportError):
    from ...dyn.drawing.text_vertical_adjust import TextVerticalAdjust as TextVerticalAdjust
with suppress(ImportError):
    from ...dyn.drawing.texture_kind import TextureKind as TextureKind
with suppress(ImportError):
    from ...dyn.drawing.texture_kind2 import TextureKind2 as TextureKind2
with suppress(ImportError):
    from ...dyn.drawing.texture_mode import TextureMode as TextureMode
with suppress(ImportError):
    from ...dyn.drawing.texture_projection_mode import TextureProjectionMode as TextureProjectionMode
with suppress(ImportError):
    from ...dyn.drawing.transparency_gradient_table import TransparencyGradientTable as TransparencyGradientTable
with suppress(ImportError):
    from ...dyn.drawing.vertical_dimensioning import VerticalDimensioning as VerticalDimensioning
with suppress(ImportError):
    from ...dyn.drawing.x_connectable_shape import XConnectableShape as XConnectableShape
with suppress(ImportError):
    from ...dyn.drawing.x_connector_shape import XConnectorShape as XConnectorShape
with suppress(ImportError):
    from ...dyn.drawing.x_control_shape import XControlShape as XControlShape
with suppress(ImportError):
    from ...dyn.drawing.x_custom_shape_engine import XCustomShapeEngine as XCustomShapeEngine
with suppress(ImportError):
    from ...dyn.drawing.x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle
with suppress(ImportError):
    from ...dyn.drawing.x_draw_page import XDrawPage as XDrawPage
with suppress(ImportError):
    from ...dyn.drawing.x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator
with suppress(ImportError):
    from ...dyn.drawing.x_draw_page_expander import XDrawPageExpander as XDrawPageExpander
with suppress(ImportError):
    from ...dyn.drawing.x_draw_page_summarizer import XDrawPageSummarizer as XDrawPageSummarizer
with suppress(ImportError):
    from ...dyn.drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier
with suppress(ImportError):
    from ...dyn.drawing.x_draw_pages import XDrawPages as XDrawPages
with suppress(ImportError):
    from ...dyn.drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier
with suppress(ImportError):
    from ...dyn.drawing.x_draw_sub_controller import XDrawSubController as XDrawSubController
with suppress(ImportError):
    from ...dyn.drawing.x_draw_view import XDrawView as XDrawView
with suppress(ImportError):
    from ...dyn.drawing.x_enhanced_custom_shape_defaulter import XEnhancedCustomShapeDefaulter as XEnhancedCustomShapeDefaulter
with suppress(ImportError):
    from ...dyn.drawing.x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier
with suppress(ImportError):
    from ...dyn.drawing.x_graphic_export_filter import XGraphicExportFilter as XGraphicExportFilter
with suppress(ImportError):
    from ...dyn.drawing.x_layer import XLayer as XLayer
with suppress(ImportError):
    from ...dyn.drawing.x_layer_manager import XLayerManager as XLayerManager
with suppress(ImportError):
    from ...dyn.drawing.x_layer_supplier import XLayerSupplier as XLayerSupplier
with suppress(ImportError):
    from ...dyn.drawing.x_master_page_target import XMasterPageTarget as XMasterPageTarget
with suppress(ImportError):
    from ...dyn.drawing.x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier
with suppress(ImportError):
    from ...dyn.drawing.x_presenter_helper import XPresenterHelper as XPresenterHelper
with suppress(ImportError):
    from ...dyn.drawing.x_selection_function import XSelectionFunction as XSelectionFunction
with suppress(ImportError):
    from ...dyn.drawing.x_shape import XShape as XShape
with suppress(ImportError):
    from ...dyn.drawing.x_shape_aligner import XShapeAligner as XShapeAligner
with suppress(ImportError):
    from ...dyn.drawing.x_shape_arranger import XShapeArranger as XShapeArranger
with suppress(ImportError):
    from ...dyn.drawing.x_shape_binder import XShapeBinder as XShapeBinder
with suppress(ImportError):
    from ...dyn.drawing.x_shape_combiner import XShapeCombiner as XShapeCombiner
with suppress(ImportError):
    from ...dyn.drawing.x_shape_descriptor import XShapeDescriptor as XShapeDescriptor
with suppress(ImportError):
    from ...dyn.drawing.x_shape_group import XShapeGroup as XShapeGroup
with suppress(ImportError):
    from ...dyn.drawing.x_shape_grouper import XShapeGrouper as XShapeGrouper
with suppress(ImportError):
    from ...dyn.drawing.x_shape_mirror import XShapeMirror as XShapeMirror
with suppress(ImportError):
    from ...dyn.drawing.x_shapes import XShapes as XShapes
with suppress(ImportError):
    from ...dyn.drawing.x_shapes2 import XShapes2 as XShapes2
with suppress(ImportError):
    from ...dyn.drawing.x_shapes3 import XShapes3 as XShapes3
with suppress(ImportError):
    from ...dyn.drawing.x_slide_preview_cache import XSlidePreviewCache as XSlidePreviewCache
with suppress(ImportError):
    from ...dyn.drawing.x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener
with suppress(ImportError):
    from ...dyn.drawing.x_slide_renderer import XSlideRenderer as XSlideRenderer
with suppress(ImportError):
    from ...dyn.drawing.x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase
with suppress(ImportError):
    from ...dyn.drawing.x_universal_shape_descriptor import XUniversalShapeDescriptor as XUniversalShapeDescriptor



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .x_color_space import XColorSpace as XColorSpace_e3940d09


class FloatingPointBitmapLayout(object):
    """
    Struct Class

    This structure describes the memory layout of a bitmap having floating point color channels.
    
    This structure collects all necessary information to describe the memory layout of a bitmap having floating point color channels
    
    **since**
    
        OOo 2.0

    See Also:
        `API FloatingPointBitmapLayout <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1FloatingPointBitmapLayout.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.FloatingPointBitmapLayout'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.FloatingPointBitmapLayout'
    """Literal Constant ``com.sun.star.rendering.FloatingPointBitmapLayout``"""

    def __init__(self, ScanLines: typing.Optional[int] = 0, ScanLineBytes: typing.Optional[int] = 0, ScanLineStride: typing.Optional[int] = 0, PlaneStride: typing.Optional[int] = 0, ColorSpace: typing.Optional[XColorSpace_e3940d09] = None, NumComponents: typing.Optional[int] = 0, Endianness: typing.Optional[int] = 0, Format: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            ScanLines (int, optional): ScanLines value.
            ScanLineBytes (int, optional): ScanLineBytes value.
            ScanLineStride (int, optional): ScanLineStride value.
            PlaneStride (int, optional): PlaneStride value.
            ColorSpace (XColorSpace, optional): ColorSpace value.
            NumComponents (int, optional): NumComponents value.
            Endianness (int, optional): Endianness value.
            Format (int, optional): Format value.
        """
        super().__init__()

        if isinstance(ScanLines, FloatingPointBitmapLayout):
            oth: FloatingPointBitmapLayout = ScanLines
            self.ScanLines = oth.ScanLines
            self.ScanLineBytes = oth.ScanLineBytes
            self.ScanLineStride = oth.ScanLineStride
            self.PlaneStride = oth.PlaneStride
            self.ColorSpace = oth.ColorSpace
            self.NumComponents = oth.NumComponents
            self.Endianness = oth.Endianness
            self.Format = oth.Format
            return

        kargs = {
            "ScanLines": ScanLines,
            "ScanLineBytes": ScanLineBytes,
            "ScanLineStride": ScanLineStride,
            "PlaneStride": PlaneStride,
            "ColorSpace": ColorSpace,
            "NumComponents": NumComponents,
            "Endianness": Endianness,
            "Format": Format,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._scan_lines = kwargs["ScanLines"]
        self._scan_line_bytes = kwargs["ScanLineBytes"]
        self._scan_line_stride = kwargs["ScanLineStride"]
        self._plane_stride = kwargs["PlaneStride"]
        self._color_space = kwargs["ColorSpace"]
        self._num_components = kwargs["NumComponents"]
        self._endianness = kwargs["Endianness"]
        self._format = kwargs["Format"]


    @property
    def ScanLines(self) -> int:
        """
        Number of scanlines for this bitmap.
        
        This value must not be negative
        """
        return self._scan_lines

    @ScanLines.setter
    def ScanLines(self, value: int) -> None:
        self._scan_lines = value

    @property
    def ScanLineBytes(self) -> int:
        """
        Number of data bytes per scanline.
        
        This value must not be negative
        """
        return self._scan_line_bytes

    @ScanLineBytes.setter
    def ScanLineBytes(self, value: int) -> None:
        self._scan_line_bytes = value

    @property
    def ScanLineStride(self) -> int:
        """
        Byte offset between the start of two consecutive scanlines.
        
        This value is permitted to be negative, denoting a bitmap whose content is flipped at the x axis.
        """
        return self._scan_line_stride

    @ScanLineStride.setter
    def ScanLineStride(self, value: int) -> None:
        self._scan_line_stride = value

    @property
    def PlaneStride(self) -> int:
        """
        Byte offset between the start of two consecutive planes.
        
        This value is permitted to be negative. If this value is zero, the bitmap is assumed to be in chunky format, otherwise it is assumed to be planar. The difference between chunky and planar layout lies in the way how color channels are interleaved. For a chunky format, all channel data for a single pixel lies consecutively in memory. For a planar layout, the first channel of all pixel is stored consecutive, followed by the second channel, and so forth.
        """
        return self._plane_stride

    @PlaneStride.setter
    def PlaneStride(self, value: int) -> None:
        self._plane_stride = value

    @property
    def ColorSpace(self) -> XColorSpace_e3940d09:
        """
        Color space the bitmap colors shall be interpreted within.
        """
        return self._color_space

    @ColorSpace.setter
    def ColorSpace(self, value: XColorSpace_e3940d09) -> None:
        self._color_space = value

    @property
    def NumComponents(self) -> int:
        """
        Number of color components per pixel.
        
        This value must not be negative
        """
        return self._num_components

    @NumComponents.setter
    def NumComponents(self, value: int) -> None:
        self._num_components = value

    @property
    def Endianness(self) -> int:
        """
        Endianness of the pixel values.
        
        This value must be one of the Endianness constants
        """
        return self._endianness

    @Endianness.setter
    def Endianness(self, value: int) -> None:
        self._endianness = value

    @property
    def Format(self) -> int:
        """
        Format type of this bitmap.
        
        This value must be one of the FloatingPointBitmapFormat constants.
        """
        return self._format

    @Format.setter
    def Format(self, value: int) -> None:
        self._format = value


__all__ = ['FloatingPointBitmapLayout']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.reflection
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_idl_member import XIdlMember as XIdlMember_e3400cfc
if typing.TYPE_CHECKING:
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a
    from com.sun.star.reflection.FieldAccessMode import FieldAccessModeProto

class XIdlField(XIdlMember_e3400cfc):
    """
    Deprecated.
    
    Use com.sun.star.reflection.XIdlField2 instead.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XIdlField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlField'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlField'

    @abstractmethod
    def get(self, obj: object) -> object:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getAccessMode(self) -> FieldAccessModeProto:
        """
        """
        ...
    @abstractmethod
    def getType(self) -> XIdlClass_d63a0c9a:
        """
        """
        ...
    @abstractmethod
    def set(self, obj: object, value: object) -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IllegalAccessException: ``IllegalAccessException``
        """
        ...

__all__ = ['XIdlField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..lang.locale import Locale as Locale_70d308fa


class LocalizedName(object):
    """
    Struct Class

    A name that is valid for a specified locale.

    See Also:
        `API LocalizedName <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1LocalizedName.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.LocalizedName'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.LocalizedName'
    """Literal Constant ``com.sun.star.sheet.LocalizedName``"""

    def __init__(self, Locale: typing.Optional[Locale_70d308fa] = UNO_NONE, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Locale (Locale, optional): Locale value.
            Name (str, optional): Name value.
        """
        super().__init__()

        if isinstance(Locale, LocalizedName):
            oth: LocalizedName = Locale
            self.Locale = oth.Locale
            self.Name = oth.Name
            return

        kargs = {
            "Locale": Locale,
            "Name": Name,
        }
        if kargs["Locale"] is UNO_NONE:
            kargs["Locale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._locale = kwargs["Locale"]
        self._name = kwargs["Name"]


    @property
    def Locale(self) -> Locale_70d308fa:
        """
        The locale for which this name is valid.
        """
        return self._locale

    @Locale.setter
    def Locale(self, value: Locale_70d308fa) -> None:
        self._locale = value

    @property
    def Name(self) -> str:
        """
        The name itself.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['LocalizedName']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb


class RuleOperator(object):
    """
    Const Class

    These are the possible values for RuleTerm.RuleOperator.

    See Also:
        `API RuleOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1RuleOperator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.RuleOperator'
    __ooo_type_name__: str = 'const'

    CONTAINS = 1
    """
    \"Contains\" - Object contains RuleTerm.Operand.
    """
    CONTAINSNOT = 2
    """
    \"ContainsNot\" - Object does not contain RuleTerm.Operand.
    """
    GREATEREQUAL = 3
    """
    \"GreaterEqual\" - Object is greater than or equal to RuleTerm.Operand.
    """
    LESSEQUAL = 4
    """
    \"LessEqual\" - Object is less than or equal to RuleTerm.Operand.
    """
    EQUAL = 5
    """
    \"Equal\" - Object is equal to RuleTerm.Operand.
    """
    NOTEQUAL = 6
    """
    \"NotEqual\" - Object is not equal to RuleTerm.Operand.
    """
    VALUE_TRUE = 7
    """
    \"True\" - Object has the value TRUE.
    """
    VALUE_FALSE = 8
    """
    \"False\" - Object has the value FALSE.
    """

__all__ = ['RuleOperator']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..frame.x_frame import XFrame as XFrame_7a570956

class XUIElement(XInterface_8f010a43):
    """
    provides a function to retrieve a special purpose interface dependent on the user interface element type.
    
    The type of the interface depends on the real type of the user interface element. A menubar user interface element provides access to its com.sun.star.awt.XSystemDependentMenuBarPeer which supports to retrieve the system dependent menu handle. A floating window or a toolbar user interface element return a com.sun.star.awt.XWindow interface.

    See Also:
        `API XUIElement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XUIElement'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XUIElement'

    @abstractmethod
    def getRealInterface(self) -> XInterface_8f010a43:
        """
        returns an interface to get access to user interface type specific functions.
        """
        ...
    @abstractproperty
    def Frame(self) -> XFrame_7a570956:
        """
        determines the document frame to which this element is bound to.
        
        The life time of a user interface element does not explicitly depend on the frame itself but on the visible component attached to the frame. It is possible to exchange the visible component of a frame and that will lead to the end of life of all user interface elements.
        """
        ...

    @abstractproperty
    def ResourceURL(self) -> str:
        """
        a resource URL which is a unique identifier of a user interface element.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        determines the type of the user interface element.
        """
        ...


__all__ = ['XUIElement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster_3d811522

class AccessibleSlideViewObject(XAccessible_1cbc0eb6, XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b, XAccessibleEventBroadcaster_3d811522):
    """
    Service Class

    The AccessibleSlideViewObject service is implemented by the slides of the slide view of Impress documents.
    
    An accessible slide view object gives access to one of the visible slides of a slide view.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleSlideViewObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleSlideViewObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleSlideViewObject'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleSlideViewObject']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TablePageBreakData(object):
    """
    Struct Class

    describes a page break in a spreadsheet.

    See Also:
        `API TablePageBreakData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1TablePageBreakData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.TablePageBreakData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.TablePageBreakData'
    """Literal Constant ``com.sun.star.sheet.TablePageBreakData``"""

    def __init__(self, Position: typing.Optional[int] = 0, ManualBreak: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Position (int, optional): Position value.
            ManualBreak (bool, optional): ManualBreak value.
        """
        super().__init__()

        if isinstance(Position, TablePageBreakData):
            oth: TablePageBreakData = Position
            self.Position = oth.Position
            self.ManualBreak = oth.ManualBreak
            return

        kargs = {
            "Position": Position,
            "ManualBreak": ManualBreak,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._manual_break = kwargs["ManualBreak"]


    @property
    def Position(self) -> int:
        """
        the position (column or row index) of the page break.
        """
        return self._position

    @Position.setter
    def Position(self, value: int) -> None:
        self._position = value

    @property
    def ManualBreak(self) -> bool:
        """
        is TRUE for a manual page break, FALSE for an automatic one.
        """
        return self._manual_break

    @ManualBreak.setter
    def ManualBreak(self, value: bool) -> None:
        self._manual_break = value


__all__ = ['TablePageBreakData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.inspection
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2

class XPropertyControlFactory(ABC):
    """
    a factory for XPropertyControls
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XPropertyControlFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControlFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.XPropertyControlFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.inspection.XPropertyControlFactory'

    @abstractmethod
    def createPropertyControl(self, ControlType: int, CreateReadOnly: bool) -> XPropertyControl_3f260fe2:
        """
        creates a XPropertyControl
        
        A XPropertyControlFactory can create any of the control types denoted by the PropertyControlType constants.
        
        If this argument is TRUE, this does not necessarily mean that the property cannot be changed at all in the ObjectInspector. Instead, an XPropertyHandler can still decide that there is a dedicated UI for entering the property value, which is usually triggered by a LineDescriptor.PrimaryButton.
        
        Note that this parameter might be ignored if the XObjectInspectorModel.IsReadOnly attribute is TRUE, in which case all created property controls must be readonly.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XPropertyControlFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod
from ...util.x_cloneable import XCloneable as XCloneable_99d00aa3
if typing.TYPE_CHECKING:
    from .x_resource_id import XResourceId as XResourceId_5be3103d
    from com.sun.star.drawing.framework.AnchorBindingMode import AnchorBindingModeProto

class XConfiguration(XCloneable_99d00aa3):
    """
    A configuration describes the resources of an application like panes, views, and tool bars and their relationships that are currently active or are requested to be activated.
    
    Resources are specified by ResourceId structures rather than references so that not only the current configuration but also a requested configuration can be represented.
    
    Direct manipulation of a configuration object is not advised with the exception of the ConfigurationController and objects that implement the XConfigurationChangeRequest interface.

    See Also:
        `API XConfiguration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfiguration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XConfiguration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XConfiguration'

    @abstractmethod
    def addResource(self, xResourceId: XResourceId_5be3103d) -> None:
        """
        Add a resource to the configuration.
        
        This method should be used only by objects that implement the XConfigurationRequest interface or by the configuration controller.
        """
        ...
    @abstractmethod
    def getResources(self, xAnchorId: XResourceId_5be3103d, sTargetURLPrefix: str, eSearchMode: AnchorBindingModeProto) -> typing.Tuple[XResourceId_5be3103d, ...]:
        """
        Returns the list of resources that are bound directly and/or indirectly to the given anchor.
        
        A URL filter can reduce the set of returned resource ids.
        
        Use an empty string to prevent filtering out resource ids.
        """
        ...
    @abstractmethod
    def hasResource(self, xResourceId: XResourceId_5be3103d) -> bool:
        """
        Returns whether the specified resource is part of the configuration.
        
        This is independent of whether the resource does really exist and is active, i.e. has a visible representation in the GUI.
        """
        ...
    @abstractmethod
    def removeResource(self, xResourceId: XResourceId_5be3103d) -> None:
        """
        Remove a resource from the configuration.
        
        This method should be used only by objects that implement the XConfigurationRequest interface or by the configuration controller.
        """
        ...

__all__ = ['XConfiguration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class GoalResult(object):
    """
    Struct Class

    is the result of a goal seek operation.

    See Also:
        `API GoalResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1GoalResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.GoalResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.GoalResult'
    """Literal Constant ``com.sun.star.sheet.GoalResult``"""

    def __init__(self, Divergence: typing.Optional[float] = 0.0, Result: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Divergence (float, optional): Divergence value.
            Result (float, optional): Result value.
        """
        super().__init__()

        if isinstance(Divergence, GoalResult):
            oth: GoalResult = Divergence
            self.Divergence = oth.Divergence
            self.Result = oth.Result
            return

        kargs = {
            "Divergence": Divergence,
            "Result": Result,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._divergence = kwargs["Divergence"]
        self._result = kwargs["Result"]


    @property
    def Divergence(self) -> float:
        """
        the amount by which the result changed in the last iteration.
        """
        return self._divergence

    @Divergence.setter
    def Divergence(self, value: float) -> None:
        self._divergence = value

    @property
    def Result(self) -> float:
        """
        the resulting value.
        """
        return self._result

    @Result.setter
    def Result(self, value: float) -> None:
        self._result = value


__all__ = ['GoalResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class UserRecord(object):
    """
    Struct Class


    See Also:
        `API UserRecord <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1task_1_1UserRecord.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.UserRecord'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.task.UserRecord'
    """Literal Constant ``com.sun.star.task.UserRecord``"""

    def __init__(self, Passwords: typing.Optional[typing.Tuple[str, ...]] = (), UserName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Passwords (typing.Tuple[str, ...], optional): Passwords value.
            UserName (str, optional): UserName value.
        """
        super().__init__()

        if isinstance(Passwords, UserRecord):
            oth: UserRecord = Passwords
            self.Passwords = oth.Passwords
            self.UserName = oth.UserName
            return

        kargs = {
            "Passwords": Passwords,
            "UserName": UserName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._passwords = kwargs["Passwords"]
        self._user_name = kwargs["UserName"]


    @property
    def Passwords(self) -> typing.Tuple[str, ...]:
        """
        specifies the passwords for the given user.
        """
        return self._passwords

    @Passwords.setter
    def Passwords(self, value: typing.Tuple[str, ...]) -> None:
        self._passwords = value

    @property
    def UserName(self) -> str:
        """
        specifies the user name.
        """
        return self._user_name

    @UserName.setter
    def UserName(self, value: str) -> None:
        self._user_name = value


__all__ = ['UserRecord']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import uno
from abc import abstractmethod, abstractproperty, ABC

class XExternalSheetCache(ABC):
    """
    Primary interface for the com.sun.star.sheet.ExternalSheetCache service.
    
    **since**
    
        OOo 3.1

    See Also:
        `API XExternalSheetCache <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetCache.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XExternalSheetCache'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XExternalSheetCache'

    @abstractmethod
    def getAllColumns(self, nRow: int) -> uno.ByteSequence:
        """
        Given a row number, this method returns a list of all columns numbers that store cached cell values in that row.
        
        The column numbers are sorted in ascending order.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getAllRows(self) -> uno.ByteSequence:
        """
        It returns a list of all row numbers where a cached cell or cells exist.
        
        The row numbers are sorted in ascending order.
        """
        ...
    @abstractmethod
    def getCellValue(self, nColumn: int, nRow: int) -> object:
        """
        It retrieves a cached value from a specified cell position.
        
        The cached value can be either string or double.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setCellValue(self, nColumn: int, nRow: int, aValue: object) -> None:
        """
        It sets a cached value for a specified cell position.
        
        The value is expected to be either of type string or of type double. No other data types are supported.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractproperty
    def TokenIndex(self) -> int:
        """
        Index corresponding to this instance of an external sheet cache for usage in formula tokens.
        
        This index to the external sheet cache is expected in the SingleReference.Sheet member if it is part of an external reference token.
        
        Each external sheet cache has a unique index value inside the ExternalDocLink instance.
        """
        ...


__all__ = ['XExternalSheetCache']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.auth
from __future__ import annotations
import uno
from abc import abstractmethod
from .xsso_context import XSSOContext as XSSOContext_a2840aec

class XSSOAcceptorContext(XSSOContext_a2840aec):
    """
    represents an acceptor side security context.
    
    This context may be used to authenticate a Single Sign-on initiator based on a security token sent by the initiator and to generate a token to be sent back to the initiator so that it can authenticate the acceptor.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSSOAcceptorContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOAcceptorContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.auth'
    __ooo_full_ns__: str = 'com.sun.star.auth.XSSOAcceptorContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.auth.XSSOAcceptorContext'

    @abstractmethod
    def accept(self, Token: uno.ByteSequence) -> uno.ByteSequence:
        """
        accepts/authenticates an SSO token sent from the context initiator side.
        
        accept() should be called only once. Subsequent calls produce undefined results.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            InvalidCredentialException: ``InvalidCredentialException``
            InvalidContextException: ``InvalidContextException``
            AuthenticationFailedException: ``AuthenticationFailedException``
        """
        ...

__all__ = ['XSSOAcceptorContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
from abc import abstractproperty
from ...awt.uno_control_radio_button_model import UnoControlRadioButtonModel as UnoControlRadioButtonModel_6ad310c3
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_reset import XReset as XReset_71670917

class RadioButton(UnoControlRadioButtonModel_6ad310c3, FormControlModel_e2990d22, XReset_71670917):
    """
    Service Class

    specifies a component which acts as a radio button as needed in HTMLForms.
    
    Radio buttons are controls which can be grouped together, and in every group, only one of the controls can be check. This means if one of them is checked by a user interaction, all other controls in the same group are automatically unchecked
    
    Like in HTML, radio buttons are grouped together if and only if they have the same name (see com.sun.star.form.FormComponent.Name).

    See Also:
        `API RadioButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RadioButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.RadioButton'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DefaultState(self) -> int:
        """
        contains a default value for the control.
        
        This value is used when the control is initially displayed, and for resetting it.
        
        In a group of radio buttons only one button should be checked by default.
        """
        ...

    @abstractproperty
    def RefValue(self) -> str:
        """
        contains a reference value which is used for submission in a HTML form.
        
        If the form the control belongs to is to be submitted (see com.sun.star.form.XSubmit), and the control is checked, this reference value is used for submission.
        """
        ...

    @abstractproperty
    def UncheckedRefValue(self) -> str:
        """
        specifies a value which is to be associated with the control when it's not selected.
        
        In various situations, the RefValue is associated with the control if and only if it is selected.UncheckedRefValue provides an extension of this concept: If present, the value should be associated with the control when it is not selected.
        """
        ...


__all__ = ['RadioButton']

